@@ -4,9 +4,12 @@ bibtutils.gcp.storage
 
 Functionality making use of GCP's Cloud Storage.
 
+See the official Cloud Storage Python Client documentation here: `link <https://googleapis.dev/python/storage/latest/index.html>`_.
+
 '''
 
 from google.cloud import storage
+import datetime
 import logging
 import json
 
@@ -18,13 +21,13 @@ def write_gcs(bucket_name, blob_name, data):
     Writes a String to GCS storage under a given blob name to the given bucket.
     The executing account must have (at least) write permissions to the bucket.
 
-    :type bucket_name: `str`
+    :type bucket_name: :py:class:`str`
     :param bucket_name: the name of the bucket to which to write.
 
-    :type blob_name: `str`
+    :type blob_name: :py:class:`str`
     :param blob_name: the name of the blob to write.
 
-    :type data: `str`
+    :type data: :py:class:`str`
     :param data: the data to be written.
     '''
     storage_client = storage.Client()
@@ -40,17 +43,17 @@ def read_gcs(bucket_name, blob_name, decode=True):
     Reads the contents of a blob from GCS. Service account must 
     have (at least) read permissions on the bucket/blob.
 
-    :type bucket_name: `str`
+    :type bucket_name: :py:class:`str`
     :param bucket_name: the bucket hosting the specified blob.
 
-    :type blob_name: `str`
+    :type blob_name: :py:class:`str`
     :param blob_name: the blob to read from GCS.
 
-    :type decode: `bool`
+    :type decode: :py:class:`bool`
     :param decode: (Optional) whether or not to decode the blob 
         contents into utf-8. Defaults to ``True``.
 
-    :rtype: `str`
+    :rtype: :py:class:`str`
     :returns: blob contents, decoded to utf-8.
     '''
     logging.info(f'Getting gs://{bucket_name}/{blob_name}')
@@ -67,17 +70,17 @@ def write_gcs_nldjson(bucket_name, blob_name, json_data, add_date=False):
     Writes a dict to GCS storage under a given blob name to the given bucket.
     The executing account must have (at least) write permissions to the bucket.
 
-    :type bucket_name: `str`
+    :type bucket_name: :py:class:`str`
     :param bucket_name: the name of the bucket to which to write.
 
-    :type blob_name: `str`
+    :type blob_name: :py:class:`str`
     :param blob_name: the name of the blob to write.
 
-    :type json_data: `dict`
+    :type json_data: :py:class:`dict`
     :param json_data: the data to be written. will be converted to 
         JSON NLD before uploading for compatibility with BQ.
 
-    :type add_date: `bool`
+    :type add_date: :py:class:`bool`
     :param add_date: (Optional) whether or not to add upload date to 
         the data before upload. Defaults to ``False``.
     '''
@@ -94,14 +97,14 @@ def _generate_json_nld(json_data, add_date):
     Takes a dict object and returns a string in JSON NLD format. 
     Compatible with uploading to BQ.
 
-    :type json_data: `dict`
+    :type json_data: :py:class:`dict`
     :param json_data: the data to be converted to JSON NLD.
 
-    :type add_date: `bool`
+    :type add_date: :py:class:`bool`
     :param add_date: whether or not to add upload date to the 
         data before upload.
 
-    :rtype: `str`
+    :rtype: :py:class:`str`
     :returns: formatted JSON NLD.
     '''
     logging.info('Generating JSON NLD...')
@@ -118,13 +121,13 @@ def read_gcs_nldjson(bucket_name, blob_name):
     '''
     Reads a blob in JSON NLD format from GCS and returns it as a dict.
 
-    :type bucket_name: `str`
+    :type bucket_name: :py:class:`str`
     :param bucket_name: the bucket hosting the specified blob.
 
-    :type blob_name: `str`
+    :type blob_name: :py:class:`str`
     :param blob_name: the blob to read from GCS.
 
-    :rtype: `dict`
+    :rtype: :py:class:`dict`
     :returns: the data from the blob, converted into a dict object.
     '''
     logging.info(f'Getting gs://{bucket_name}/{blob_name}')
